diff --git a/ssh/generate.go b/ssh/generate.go
index e143d996..deda20c7 100644
--- a/ssh/generate.go
+++ b/ssh/generate.go
@@ -20,9 +20,9 @@ var rsaGenerateKey = rsa.GenerateKey
 
 // KeyBits is used to determine the number of bits to use for the RSA keys
 // created using the GenerateKey function.
-var KeyBits = 2048
+var KeyBits = 3072
 
 // GenerateKey makes a 2048 bit RSA no-passphrase SSH capable key.  The bit
 // size is actually controlled by the KeyBits var. The private key returned is
 // encoded to ASCII using the PKCS1 encoding.  The public key is suitable to
 // be added into an authorized_keys file, and has the comment passed in as the
@@ -20,9 +20,9 @@ var rsaGenerateKey = rsa.GenerateKey
 
-// GenerateKey makes a 2048 bit RSA no-passphrase SSH capable key.  The bit
+// GenerateKey makes a 3072 bit RSA no-passphrase SSH capable key.  The bit
 // size is actually controlled by the KeyBits var. The private key returned is
 // encoded to ASCII using the PKCS1 encoding.  The public key is suitable to